package sun.security.provider.certpath;

import java.security.cert.CertSelector;
import java.security.cert.CertStore;
import java.util.List;
import java.security.cert.TrustAnchor;
import java.util.Set;
import java.security.cert.PKIXCertPathChecker;
import java.util.Date;
import java.security.InvalidAlgorithmParameterException;
import java.security.Timestamp;
import java.security.cert.PKIXBuilderParameters;

public class PKIXExtendedParameters extends PKIXBuilderParameters
{
    private final PKIXBuilderParameters p;
    private Timestamp jarTimestamp;
    private final String variant;
    
    public PKIXExtendedParameters(PKIXBuilderParameters p3, Timestamp jarTimestamp, String variant) throws InvalidAlgorithmParameterException {
        super(p3.getTrustAnchors(), null);
        this.p = p3;
        this.jarTimestamp = jarTimestamp;
        this.variant = variant;
    }
    
    public Timestamp getTimestamp() {
        return this.jarTimestamp;
    }
    
    public void setTimestamp(Timestamp jarTimestamp) {
        this.jarTimestamp = jarTimestamp;
    }
    
    public String getVariant() {
        return this.variant;
    }
    
    @Override
    public void setDate(Date date) {
        this.p.setDate(date);
    }
    
    @Override
    public void addCertPathChecker(PKIXCertPathChecker checker) {
        this.p.addCertPathChecker(checker);
    }
    
    @Override
    public void setMaxPathLength(int maxPathLength) {
        this.p.setMaxPathLength(maxPathLength);
    }
    
    @Override
    public int getMaxPathLength() {
        return this.p.getMaxPathLength();
    }
    
    @Override
    public String toString() {
        return this.p.toString();
    }
    
    @Override
    public Set<TrustAnchor> getTrustAnchors() {
        return this.p.getTrustAnchors();
    }
    
    @Override
    public void setTrustAnchors(Set<TrustAnchor> trustAnchors) throws InvalidAlgorithmParameterException {
        if (this.p == null) {
            return;
        }
        this.p.setTrustAnchors(trustAnchors);
        return;
    }
    
    @Override
    public Set<String> getInitialPolicies() {
        return this.p.getInitialPolicies();
    }
    
    @Override
    public void setInitialPolicies(Set<String> initialPolicies) {
        this.p.setInitialPolicies(initialPolicies);
    }
    
    @Override
    public void setCertStores(List<CertStore> certStores) {
        this.p.setCertStores(certStores);
    }
    
    @Override
    public void addCertStore(CertStore store) {
        this.p.addCertStore(store);
    }
    
    @Override
    public List<CertStore> getCertStores() {
        return this.p.getCertStores();
    }
    
    @Override
    public void setRevocationEnabled(boolean revocationEnabled) {
        this.p.setRevocationEnabled(revocationEnabled);
    }
    
    @Override
    public boolean isRevocationEnabled() {
        return this.p.isRevocationEnabled();
    }
    
    @Override
    public void setExplicitPolicyRequired(boolean explicitPolicyRequired) {
        this.p.setExplicitPolicyRequired(explicitPolicyRequired);
    }
    
    @Override
    public boolean isExplicitPolicyRequired() {
        return this.p.isExplicitPolicyRequired();
    }
    
    @Override
    public void setPolicyMappingInhibited(boolean policyMappingInhibited) {
        this.p.setPolicyMappingInhibited(policyMappingInhibited);
    }
    
    @Override
    public boolean isPolicyMappingInhibited() {
        return this.p.isPolicyMappingInhibited();
    }
    
    @Override
    public void setAnyPolicyInhibited(boolean anyPolicyInhibited) {
        this.p.setAnyPolicyInhibited(anyPolicyInhibited);
    }
    
    @Override
    public boolean isAnyPolicyInhibited() {
        return this.p.isAnyPolicyInhibited();
    }
    
    @Override
    public void setPolicyQualifiersRejected(boolean policyQualifiersRejected) {
        this.p.setPolicyQualifiersRejected(policyQualifiersRejected);
    }
    
    @Override
    public boolean getPolicyQualifiersRejected() {
        return this.p.getPolicyQualifiersRejected();
    }
    
    @Override
    public Date getDate() {
        return this.p.getDate();
    }
    
    @Override
    public void setCertPathCheckers(List<PKIXCertPathChecker> certPathCheckers) {
        this.p.setCertPathCheckers(certPathCheckers);
    }
    
    @Override
    public List<PKIXCertPathChecker> getCertPathCheckers() {
        return this.p.getCertPathCheckers();
    }
    
    @Override
    public String getSigProvider() {
        return this.p.getSigProvider();
    }
    
    @Override
    public void setSigProvider(String sigProvider) {
        this.p.setSigProvider(sigProvider);
    }
    
    @Override
    public CertSelector getTargetCertConstraints() {
        return this.p.getTargetCertConstraints();
    }
    
    @Override
    public void setTargetCertConstraints(CertSelector targetCertConstraints) {
        if (this.p == null) {
            return;
        }
        this.p.setTargetCertConstraints(targetCertConstraints);
        return;
    }
}
